@@ -15,7 +15,7 @@ class Produto(core.models.Log):
     tipo_produto = models.ForeignKey('produto.Tipo', on_delete=models.DO_NOTHING, null=True)
     fabricante = models.ForeignKey('fornecedor.Fabricante', on_delete=models.DO_NOTHING, null=True)
 
-    imagem = models.FileField(upload_to="produtos", default='produtos/caixa-nissei.jpg')
+    imagem = models.FileField(upload_to="produtos", default='produtos/caixa-nissei.jpg', null=True)
 
     produto_pai = models.ForeignKey('self', models.DO_NOTHING, null=True)
 
@@ -67,7 +67,7 @@ class Marca(core.models.Log):
 
 class ProdutoImagem(core.models.Log):
     produto = models.ForeignKey('produto.Produto', on_delete=models.DO_NOTHING, null=True)
-    imagem = models.FileField(upload_to="produtos-imagens", default='produtos/caixa-nissei.jpg')
+    imagem = models.FileField(upload_to="produtos", default='produtos/caixa-nissei.jpg', null=True)
 
     class Meta(core.models.Log.Meta):
         abstract = False
